Package {NeutroRCDsAnalysis}


Type: Package
Title: Neutrosophic Analysis of Row Column Designs
Version: 0.1.0
Maintainer: Vinaykumar L.N. <vinaymandya123@gmail.com>
Description: Description: Provides methods for Neutrosophic Analysis of Variance (NANOVA) and Neutrosophic Analysis of Covariance (NANCOVA) for row-column designs, including Latin square designs and Youden square designs, using interval-valued observations. The package computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and multiple comparisons using Least Significant Difference (LSD) procedures. For crisp data, users may enter identical lower and upper values of responses to obtain classical Analysis of Variance (ANOVA) results. Similarly, users may enter identical lower and upper values for both responses and covariates to obtain classical Analysis of Covariance (ANCOVA) results.
License: GPL-3
Encoding: UTF-8
Depends: R (≥ 4.0.0)
Imports: MASS
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-06-02 09:37:17 UTC; admin
Author: Neethu R.S. [aut, ctb], Cini Varghese [aut, ctb], Mohd Harun [aut, ctb], Anindita Datta [aut, ctb], Vinaykumar L.N. [aut, cre]
Repository: CRAN
Date/Publication: 2026-06-08 17:50:26 UTC

Neutrosophic Analysis of Covariance for Latin Square Design

Description

Performs Neutrosophic Analysis of Covariance (NANCOVA) for Latin square designs using interval-valued response and covariate observations. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based treatment comparisons. For crisp data, enter identical lower and upper values to obtain the corresponding classical ANCOVA results.

Usage

LSDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE)

Arguments

Lower_y

Matrix containing lower bounds of response observations.

Upper_y

Matrix containing upper bounds of response observations.

Lower_z

Matrix containing lower bounds of covariate observations.

Upper_z

Matrix containing upper bounds of covariate observations.

design

Matrix representing Latin square treatment allocation.

alpha

Significance level for the F-test and LSD test.Default is 0.05.

verbose

Logical. If TRUE, displays the ANCOVA table, LSD interval, treatment comparisons and significance codes. Default is FALSE.

Details

Input matrix structure:

Value

A list containing:

Examples

Lower_y <- matrix(c(
18.86,15.49,18.62,16.37,12.04,
18.23,26.80,26.70,15.89,16.96,
26.26,12.16,27.15,18.30,22.93,
25.31,26.71,18.36,9.98,28.34,
29.78,21.20,21.99,18.97,18.71
), nrow = 5, byrow = TRUE)

Upper_y <- matrix(c(
21.14,22.51,25.38,21.63,19.96,
27.77,29.20,33.30,18.11,25.04,
29.74,19.84,36.85,25.70,31.07,
34.69,29.29,21.64,18.02,33.66,
32.22,28.80,24.01,25.03,21.29
), nrow = 5, byrow = TRUE)

Lower_z <- matrix(c(
9.11,7.39,7.09,4.10,5.92,
6.91,4.26,13.10,5.86,12.54,
8.89,4.98,4.32,8.80,9.77,
6.40,7.28,3.29,3.81,4.45,
6.42,2.51,6.06,3.25,5.73
), nrow = 5, byrow = TRUE)

Upper_z <- matrix(c(
16.89,10.61,14.91,9.90,8.08,
11.09,9.74,16.90,12.14,17.46,
13.11,11.02,11.68,11.20,18.23,
9.60,12.72,10.71,8.19,7.55,
15.58,7.49,9.94,12.75,14.27
), nrow = 5, byrow = TRUE)

design <- matrix(c(
2,1,5,4,3,
1,4,3,5,2,
3,2,4,1,5,
5,3,1,2,4,
4,5,2,3,1
), nrow = 5, byrow = TRUE)

LSDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = TRUE)


Neutrosophic Analysis of Variance for Latin Square Design

Description

Performs Neutrosophic Analysis of Variance (NANOVA) for Latin square designs using interval-valued observations. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based treatment comparisons. When the data are crisp, identical lower and upper values may be entered to obtain the corresponding classical ANOVA results.

Usage

LSDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = FALSE)

Arguments

Lower_y

Matrix containing lower bounds of observations.

Upper_y

Matrix containing upper bounds of observations.

design

Matrix representing Latin square treatment allocation.

alpha

Significance level (default is 0.05.) for the F-test and LSD test.

verbose

Logical. If TRUE, displays the NANOVA table, LSD interval, treatment comparisons, and significance codes. Default is FALSE.

Details

Input matrix structure:

Value

A list containing:

Examples

Lower_y <- matrix(c(
243.28,233.45,232.41,239.27,
237.38,223.30,240.86,240.33,
232.12,234.67,230.45,220.81,
219.26,231.43,248.44,227.88
), nrow = 4, byrow = TRUE)

Upper_y <- matrix(c(
246.72,238.55,237.59,242.73,
242.62,226.70,245.14,245.67,
235.88,239.33,233.55,223.19,
224.74,236.57,253.57,230.12
), nrow = 4, byrow = TRUE)

design <- matrix(c(
3,4,2,1,
1,2,4,3,
4,3,1,2,
2,1,3,4
), nrow = 4, byrow = TRUE)

LSDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05, verbose = TRUE)


Neutrosophic Analysis of Covariance for Youden Square Design

Description

Performs Neutrosophic Analysis of Covariance (NANCOVA) for Youden square designs using interval-valued observations and covariates. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based treatment comparisons. For crisp data, enter identical lower and upper values to obtain the corresponding classical ANCOVA results.

Usage

YSDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05, verbose = FALSE)

Arguments

Lower_y

Matrix containing lower bounds of response observations.

Upper_y

Matrix containing upper bounds of response observations.

Lower_z

Matrix containing lower bounds of covariate observations.

Upper_z

Matrix containing upper bounds of covariate observations.

design

Matrix representing Youden square treatment allocation.

alpha

Significance level for the F-test and LSD test. Default is 0.05.

verbose

Logical. If TRUE, prints the ANCOVA table, LSD interval, treatment comparisons and significance codes. Default is FALSE.

Details

Input matrix structure:

Value

A list containing:

Examples

Lower_y <- matrix(c(
2.06,2.34,0.13,15.63,15.72,8.18,292.48,
15.39,218.67,10.02,13.67,8.90,25.23,24.86,
35.78,24.90,308.36,19.96,22.01,20.17,28.99,
45.05,42.44,33.19,280.58,31.40,31.82,28.41
), nrow = 4, byrow = TRUE)

Upper_y <- matrix(c(
5.94,8.26,2.33,18.17,18.08,12.42,295.52,
19.61,221.33,14.38,17.33,13.10,27.77,29.54,
38.22,27.10,311.64,25.44,26.39,22.63,33.60,
48.55,45.96,35.41,283.42,36.00,35.58,32.59
), nrow = 4, byrow = TRUE)

Lower_z <- matrix(c(
10.57,269.93,224.08,260.05,257.81,257.58,13.76,
246.72,7.42,216.00,257.15,232.38,237.91,215.32,
246.50,215.17,2.63,257.26,267.90,212.10,254.15,
262.67,250.51,250.45,6.09,245.01,228.31,258.90
), nrow = 4, byrow = TRUE)

Upper_z <- matrix(c(
13.43,272.07,227.92,265.95,260.19,260.42,18.24,
249.28,12.58,220.00,262.85,235.62,240.09,218.68,
251.50,220.83,7.37,260.74,272.10,215.90,257.85,
265.33,253.49,253.55,11.91,250.99,231.69,263.10
), nrow = 4, byrow = TRUE)

design <- matrix(c(
2,3,4,5,6,7,1,
7,1,2,3,4,5,6,
6,7,1,2,3,4,5,
5,6,7,1,2,3,4
), nrow = 4, byrow = TRUE)

YSDnsANCOVA(Lower_y, Upper_y, Lower_z, Upper_z, design, alpha = 0.05,  verbose = TRUE)


Neutrosophic Analysis of Variance for Youden Square Design

Description

Performs Neutrosophic Analysis of Variance (NANOVA) for Youden square designs using interval-valued observations. The function computes neutrosophic sums of squares, mean squares, interval-valued F-statistics, significance tests, and Least Significant Difference (LSD)-based treatment comparisons. For crisp data, enter identical lower and upper values to obtain the corresponding classical ANOVA results.

Usage

YSDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05,  verbose = FALSE)

Arguments

Lower_y

Matrix containing lower bounds of observations.

Upper_y

Matrix containing upper bounds of observations.

design

Matrix representing Youden square treatment allocation.

alpha

Significance level for the F-test and LSD test. Default is 0.05.

verbose

Logical. If TRUE, displays the NANOVA table, LSD interval, treatment comparisons and significance codes. Default is FALSE.

Details

Input matrix structure:

Value

A list containing:

Examples

Lower_y <- matrix(c(
4.51,7.77,3.53,7.92,5.97,7.42,6.37,
6.37,4.36,4.68,8.19,6.08,6.80,4.86,
4.88,4.64,8.69,7.81,9.50,9.60,9.10,
8.05,7.92,5.61,8.41,6.53,11.36,5.94
), nrow = 4, byrow = TRUE)

Upper_y <- matrix(c(
8.12,11.06,6.44,11.16,8.30,10.17,9.81,
10.31,7.50,8.01,10.82,8.49,10.69,7.77,
7.76,7.24,10.82,11.04,13.20,11.63,11.59,
11.66,10.45,8.92,12.03,8.95,14.64,9.14
), nrow = 4, byrow = TRUE)

design <- matrix(c(
2,3,4,5,6,7,1,
7,1,2,3,4,5,6,
6,7,1,2,3,4,5,
5,6,7,1,2,3,4
), nrow = 4, byrow = TRUE)

YSDnsANOVA(Lower_y, Upper_y, design, alpha = 0.05,  verbose = TRUE)